<h1 align="center">detapack 📄</h1>
<p align="center"><strong>Import/Export data from/to Deta Bases</strong></p>
<p align="center">
    <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/detapack">
    <img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/detapack">
    <img alt="PyPI" src="https://img.shields.io/pypi/v/detapack">
    <img alt="GitHub last commit" src="https://img.shields.io/github/last-commit/berrysauce/detapack">
</p>

## What is detapack?
detapack is a tiny & simple CLI built with [Typer](https://github.com/tiangolo/typer) (in Python) which can import and export data from and to Deta Bases.

## How to install detapack?
detapack can be installed the Python Package Index.
```
pip install detapack
```
Run `detapack version` to check if detapack was installed successfully. You may need to add detapack to your shell configuration.